aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/initial-boot.sh
diff options
context:
space:
mode:
authorJaKooLit <jimmielovejay@gmail.com>2024-05-10 02:03:31 +0900
committerJaKooLit <jimmielovejay@gmail.com>2024-05-10 02:03:31 +0900
commitd7ff1c1dea16619a38f35536a5c00685d848abce (patch)
treef5c9ea6aeca1fb713d31a1d2d3069c5b9830ddc0 /config/hypr/initial-boot.sh
parenta3994cc8edd41fa42dfe1a6f22754dcdcc3d1e51 (diff)
Initial Push - Moving to Wallust from Pywal
Diffstat (limited to 'config/hypr/initial-boot.sh')
-rwxr-xr-xconfig/hypr/initial-boot.sh11
1 files changed, 4 insertions, 7 deletions
diff --git a/config/hypr/initial-boot.sh b/config/hypr/initial-boot.sh
index f5fe66d7..34f0af90 100755
--- a/config/hypr/initial-boot.sh
+++ b/config/hypr/initial-boot.sh
@@ -8,7 +8,7 @@
# Variables
scriptsDir=$HOME/.config/hypr/scripts
wallpaper=$HOME/Pictures/wallpapers/Lofi-Urban-Nightscape.png
-waybar_style="$HOME/.config/waybar/style/[Pywal] Chroma Tally.css"
+waybar_style="$HOME/.config/waybar/style/[Wallust] Chroma Tally.css"
kvantum_theme="Catppuccin-Mocha"
swww="swww img"
@@ -17,16 +17,13 @@ effect="--transition-bezier .43,1.19,1,.4 --transition-fps 30 --transition-type
# Check if a marker file exists.
if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
# Initialize pywal and wallpaper
if [ -f "$wallpaper" ]; then
- wal -i $wallpaper -s -t > /dev/null
+ wallust run -s $wallpaper > /dev/null
swww query || swww-daemon && $swww $wallpaper $effect
- "$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
+ "$scriptsDir/WallustSwww.sh" > /dev/null 2>&1 &
fi
- # Initial symlink for Pywal Dark and Light for Rofi Themes
- ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi" > /dev/null 2>&1 &
-
# initiate GTK dark mode and apply icon and cursor theme
gsettings set org.gnome.desktop.interface color-scheme prefer-dark > /dev/null 2>&1 &
gsettings set org.gnome.desktop.interface gtk-theme Tokyonight-Dark-BL-LB > /dev/null 2>&1 &
@@ -17,16 +17,13 @@ effect="--transition-bezier .43,1.19,1,.4 --transition-fps 30 --transition-type
# Check if a marker file exists.
if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
- # Initialize pywal and wallpaper
+ # Initialize wallust and wallpaper
if [ -f "$wallpaper" ]; then
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage